C=======================================================================
C=======================================================================
C
C    University of Maryland Baltimore County [UMBC]
C
C    NAST
C
C    incFTC
C
!F77====================================================================


!ROUTINE NAME:
C    incFTC (include file)


!ABSTRACT:
C    Include file consisting of parameter statements to size various
C    arrays in the USEFAST related routines source code.


!CALL PROTOCOL:
C    none (include file)


!INPUT PARAMETERS:
C    none


!OUTPUT PARAMETERS:
C    none


!INPUT/OUTPUT PARAMETERS:
C    none


!RETURN VALUES:
C    none


!PARENT(S):
C    CALPAR
C    CALT1
C    CALT2
C    CALT3
C    CALT4
C    CALT5
C    CALRAD
C    FAKETZ
C    RDCOEF
C    RDLIST
C    RDPROF
C    RDSUN
C    SUNPAR
C    USEFAST


!ROUTINES CALLED:
C    none


!FILES ACCESSED:
C    none


!COMMON BLOCKS
C    none


!DESCRIPTION:
C    August 1998 version of the 65 layer NAST Fast Transmittance Code
C    by Howard Motteler/Larrabee Strow/Scott Hannon.
C
C    Parameter statements for the FTC routines.


!ALGORITHM REFERENCES:
C    none


!KNOWN BUGS AND LIMITATIONS:
C    none


!ROUTINE HISTORY:
C    Date         Programmer      Comments
C    -----------  --------------  --------------------------------------
C     7 Aug 1998  Scott Hannon    Created based on Jul98 HIS version
C    28 Aug 1998  Scott Hannon    Finished creating initial version


!END====================================================================
C
C-----------------------------------------------------------------------
C      IMPLICIT NONE
C-----------------------------------------------------------------------
       IMPLICIT NONE


C-----------------------------------------------------------------------
C      INCLUDE FILES
C-----------------------------------------------------------------------
C      none


C-----------------------------------------------------------------------
C      EXTERNAL FUNCTIONS
C-----------------------------------------------------------------------
C      none


C-----------------------------------------------------------------------
C      ARGUMENTS
C-----------------------------------------------------------------------
C      none (but see below)


C-----------------------------------------------------------------------
C      LOCAL VARIABLES
C-----------------------------------------------------------------------
C      none


C-----------------------------------------------------------------------
C      SAVE STATEMENTS
C-----------------------------------------------------------------------
C      none


C-----------------------------------------------------------------------
C      EXECUTABLE CODE
C-----------------------------------------------------------------------
C      none
C
C      Include file for the August 1998 version of the 65 layer NAST
C      Rapid Transmittance Algorithm test program.
C
C      Note: these should not be changed by the user

C      ------------------------
C      Constants and other data
C      ------------------------
       REAL     PI ! pi, circle circumference/diameter (3.1415926)
       REAL RADSUN ! radius of the sun (6.956E+8 m)
       REAL     C1 ! radiation constant c1 (1.1911E-8  W/(m2.st.(cm-1)4)
       REAL     C2 ! radiation constant c2 (1.4387863 K/cm-1)
       PARAMETER(    PI = 3.1415926)
       PARAMETER(RADSUN = 6.956E+8)
       PARAMETER(    C1 = 1.1911E-8)
       PARAMETER(    C2 = 1.4387863)
C
C      -----------------------------------
C      Channels and layers other variables
C      -----------------------------------
C      MAXLAY= number of layers (65)
C      NSETS = number of coef data sets (4)
C      MXBND1= number of channels in band1 (3526)
C      MXBND2= number of channels in band2 (4149)
C      MXBND3= number of channels in band3 (3630)
C      MXCHAN= maximum total number of channels (3526+4149+3630)
       INTEGER MAXLAY
       INTEGER   NSET
       INTEGER MXBND1
       INTEGER MXBND2
       INTEGER MXBND3
       INTEGER MXCHAN
       INTEGER NFCOEF
       PARAMETER( MAXLAY=65 )
       PARAMETER( NSET=4 )
       PARAMETER( MXBND1=3526 )
       PARAMETER( MXBND2=4149 )
       PARAMETER( MXBND3=3630 )
       PARAMETER( MXCHAN = MXBND1 + MXBND2 + MXBND3 )
       PARAMETER( NFCOEF=5 )
C
C
C      --------------
C      For set1 = FOW bf
C      --------------
C      MXCHN1 = max number of channels for set1 = FOW bf (3730)
C      N1CON  = number of water continuum predictors/coefs for set1 (4)
C      N1FIX  = number of "fixed" predictors/coefs for set1 (11)
C      N1O3   = number of ozone predictors/coefs for set1 (5)
C      N1H2O  = number of water predictors/coefs for set1 (7)
C      N1COEF = total number of coefs for set1
       INTEGER MXCHN1
       INTEGER  N1CON
       INTEGER  N1FIX
       INTEGER   N1O3
       INTEGER  N1H2O
       INTEGER N1COEF
       PARAMETER( MXCHN1=3730 )
       PARAMETER( N1CON=4 )
       PARAMETER( N1FIX=11 )
       PARAMETER( N1O3=5 )
       PARAMETER( N1H2O=7 )
       PARAMETER( N1COEF=N1CON + N1FIX + N1O3 + N1H2O )
C
C
C      --------------
C      For set2 = FOW bo
C      --------------
C      MXCHN2 = max number of channels for set2 = FOW  (621)
C      N2CON  = number of water continuum predictors/coefs for set2 (4)
C      N2FIX  = number of "fixed" predictors/coefs for set2 (8)
C      N2O3   = number of ozone predictors/coefs for set2 (10)
C      N2H2O  = number of water predictors/coefs for set2 (11)
C      N2COEF = total number of coefs for set2
       INTEGER MXCHN2
       INTEGER  N2CON
       INTEGER  N2FIX
       INTEGER   N2O3
       INTEGER  N2H2O
       INTEGER N2COEF
       PARAMETER( MXCHN2=621 )
       PARAMETER( N2CON=4 )
       PARAMETER( N2FIX=8 )
       PARAMETER( N2O3=10 )
       PARAMETER( N2H2O=11 )
       PARAMETER( N2COEF=N2CON + N2FIX + N2O3 + N2H2O )
C
C
C      --------------
C      For set3 = FOW bw
C      --------------
C      MXCHN3 = max number of channels for set3 = FOW bw  (6172)
C      N3CON  = number of water continuum predictors/coefs for set3 (4)
C      N3FIX  = number of "fixed" predictors/coefs for set3 (8)
C      N3O3   = number of ozone predictors/coefs for set3 (7)
C      N3H2O  = number of water predictors/coefs for set3 (3)
C      N3COEF = total number of coefs for set3
       INTEGER MXCHN3
       INTEGER  N3CON
       INTEGER  N3FIX
       INTEGER   N3O3
       INTEGER  N3H2O
       INTEGER N3COEF
       PARAMETER( MXCHN3=6172 )
       PARAMETER( N3CON=4 )
       PARAMETER( N3FIX=8 )
       PARAMETER( N3O3=3 )
       PARAMETER( N3H2O=13 )
       PARAMETER( N3COEF=N3CON + N3FIX + N3O3 + N3H2O )
C
C
C      --------------
C      For set4 = FCOW
C      --------------
C      MXCHN4 = max number of channels for set4 = FCOW sun  (782)
C      N4CON  = number of water continuum predictors/coefs for set4 (4)
C      N4FIX  = number of "fixed" predictors/coefs for set4 (11)
C      N4O3   = number of CO predictors/coefs for set4 (11)
C      N4O3   = number of ozone predictors/coefs for set4 (9)
C      N4H2O  = number of water predictors/coefs for set4 (13)
C      N4COEF = total number of coefs for set4
       INTEGER MXCHN4
       INTEGER  N4CON
       INTEGER  N4FIX
       INTEGER   N4CO
       INTEGER   N4O3
       INTEGER  N4H2O
       INTEGER N4COEF
       PARAMETER( MXCHN4=782 )
       PARAMETER( N4CON=4 )
       PARAMETER( N4FIX=11 )
       PARAMETER( N4CO =11 )
       PARAMETER( N4O3 =9 )
       PARAMETER( N4H2O=13 )
       PARAMETER( N4COEF=N4CON + N4FIX + N4CO + N4O3 + N4H2O )
C
C
C      End of include file
