C=======================================================================
C=======================================================================
C
C    University of Maryland Baltimore Country (UMBC)
C
C    NAST
C
C    RDLIST
C
!F77====================================================================


!ROUTINE NAME:
C    RDLIST


!ABSTRACT:
C    Read the channel list. The channel list specifies some sub-set of
C    the total NAST channels for which the program is to do its
C    calculations.


!CALL PROTOCOL
C    RDLIST ( IOUN, NCHAN, LSTCHN, INDCHN )


!INPUT PARAMETERS:
C    type      name    purpose                     units
C    --------  ------  --------------------------  ---------------------
C    INTEGER   IOUN    I/O unit number             none


!OUTPUT PARAMETERS:
C    type      name    purpose                     units
C    --------  ------  --------------------------  ---------------------
C    INT arr   INDCHN  array indices of channels   none
C    INT arr   LSTCHN  list of channels            none
C    INTEGER   NCHAN   number of channels          none


!INPUT/OUTPUT PARAMETERS:
C    none


!RETURN VALUES:
C    none


!PARENT(S):
C    USEFAST


!ROUTINES CALLED:
C    none


!FILES ACCESSED:
C    incFTC.f : include file of parameter statements accessed during
C       compilation only.
C    unit IOUN : text file, channel list


!COMMON BLOCKS
C    none


!DESCRIPTION:
C    August 1998 version of the 65 layer NAST Fast Transmittance
C    Code by Howard Motteler/Larrabee Strow/Scott Hannon.
C
C    Asks for the file names of the channel list. It opens the file and
C    reads it. If it detects a problem it writes an error message and
C    quits. Otherwise the routine loads up the channel list array
C    LSTCHN and the channel index array INDCHN and then exits.
C
C    LSTCHN is a list of the channel numbers to be used.
C    INDCHN is the array indices of the channels in LSTCHN.
C
C    The channel list is a text file, and may contain a header of an
C    arbitrary number of comment lines. A comment line is any line
C    beginning with the "!" character. The main body of the channel
C    list is a column of integers which represent the desired channel
C    numbers. Only the first number (integer) on each line is read in;
C    comments may follow the channel number specifier on a line.


!ALGORITHM REFERENCES:
C    none


!KNOWN BUGS AND LIMITATIONS:
C    none


!ROUTINE HISTORY:
C    Date         Programmer      Comments
C    -----------  --------------  --------------------------------------
C     7 Aug 1998  Scott Hannon    Created copied from Jul98 HIS version


!END====================================================================

C      =================================================================
       SUBROUTINE RDLIST ( IOUN, NCHAN, LSTCHN, INDCHN )
C      =================================================================


C-----------------------------------------------------------------------
C      IMPLICIT NONE
C-----------------------------------------------------------------------
       IMPLICIT NONE


C-----------------------------------------------------------------------
C      INCLUDE FILES
C-----------------------------------------------------------------------
#include "incFTC.f"


C-----------------------------------------------------------------------
C      EXTERNAL FUNCTIONS
C-----------------------------------------------------------------------
C      none


C-----------------------------------------------------------------------
C      ARGUMENTS
C-----------------------------------------------------------------------
C      Input
       INTEGER   IOUN
C
C      Output
       INTEGER  NCHAN
       INTEGER LSTCHN(MXCHAN)
       INTEGER INDCHN(MXCHAN)


C-----------------------------------------------------------------------
C      LOCAL VARIABLES
C-----------------------------------------------------------------------
       INTEGER      I
       INTEGER   IERR
       INTEGER      J
       CHARACTER*80  CLINE


C-----------------------------------------------------------------------
C      SAVE STATEMENTS
C-----------------------------------------------------------------------
C      none


C***********************************************************************
C***********************************************************************
C                    EXECUTABLE CODE
C***********************************************************************
C***********************************************************************
C
C
C      ----------------------------------
C      Initialize the channel index array
C      ----------------------------------
       DO I=1,MXCHAN
          INDCHN(I)=0
       ENDDO
C
C      -----------------------------------
C      Get name and open channel list file
C      -----------------------------------
       WRITE(6,1020)
 1020  FORMAT('Enter the name of the channel list file:')
       READ(5,9000) CLINE
 9000  FORMAT(A80)
C
C      Open the channel list text file
       OPEN(UNIT=IOUN,FILE=CLINE,FORM='FORMATTED',STATUS='OLD',
     $    IOSTAT=IERR)
       IF (IERR .NE. 0) THEN
          WRITE(6,1030) IERR, CLINE
 1030     FORMAT('Error ',I5,' opening channel list file:',/,A80)
          STOP
       ENDIF
C
C      ------------------------------
C      Initialize the channel counter
C      ------------------------------
       NCHAN=0

C      --------------------------
C      Read the channel list file
C      --------------------------
C      Read a line of text from the channel list file
 10    READ(IOUN,9000,END=910) CLINE
C
       IF (CLINE(1:1) .NE. '!') THEN
C         It's data, not a comment
          READ(CLINE,*) J
C
C         Check to be sure the value is OK
          IF ((J .LT. 1) .OR. (J .GT. MXCHAN)) THEN
             WRITE(6,1040) MXCHAN, J
 1040        FORMAT('Error! Channel number is out of range.',/,
     $       'Range is 1 to ',I4,', but channel list has ',I7,'.')
             STOP
          ENDIF
C
C         If the channel is not a repeat, update the channel info
          IF (INDCHN(J) .EQ. 0) THEN
             NCHAN=NCHAN + 1
             LSTCHN(NCHAN)=J
             INDCHN(J)=NCHAN
          ELSE
             WRITE(6,1050) J
 1050        FORMAT('Warning! Channel list contains repeat of ',
     $       'channel ',I4,'. Repeat ignored.')
          ENDIF
       ENDIF
C
C      Read the next line
       IF (NCHAN .LT. MXCHAN) GOTO 10
C
 910   CLOSE(IOUN)
C
C      ----------------------------
C      Show summary of channel list
C      ----------------------------
       WRITE(6,1060) NCHAN
 1060  FORMAT('Number of channels selected = ',I4)
C
       RETURN
       END
